# RevenueRecognitionRuleName

Specifies the revenue recognition rule.    * `Recognize upon invoicing`   * `Recognize daily over time` 

## Enum

* `RECOGNIZE_UPON_INVOICING` (value: `'Recognize upon invoicing'`)

* `RECOGNIZE_DAILY_OVER_TIME` (value: `'Recognize daily over time'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


